@@ -41,8 +41,8 @@
  * @param[in,out] s_file   Config file path or null to use default
  * @param[in]     i_create Create config file if it doesn't exist
  */
-int cfgfile_config_file_stuff (char **s_file,
-                               int    i_create);
+int    cfgfile_config_file_stuff       (char **s_file,
+                                        int    i_create);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Get path for autostart desktop file for wchangerd daemon.
@@ -50,15 +50,46 @@ int cfgfile_config_file_stuff (char **s_file,
  * @return String with autostart file path.
  *         After use it should be freed using free.
  */
-char * cfgfile_get_autostart_file_path (void);
+char * cfgfile_get_autostart_home_path (void);
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Get path for config file with window manager info.
+ * @brief  Get path for user's config file with window manager info.
  *
  * @return String with window manager info file path.
  *         After use it should be freed using free.
  */
-char * cfgfile_get_wm_info_file_path (void);
+char * cfgfile_get_wm_info_home_path   (void);
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get path for default config file with window manager info.
+ *
+ * @param[out] i_err  Error output
+ * @return     String with window manager info file path or null.
+ *             After use it should be freed using free.
+ */
+char * cfgfile_get_wm_info_data_path   (int *i_err);
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Check if wchangerd daemon desktop file exists in user's autostart
+ *         directory.
+ *
+ * @return 1 if file exists, 0 if not or there was some problem with it.
+ */
+int    cfgfile_autostart_exists        (void);
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Creates wchangerd desktop file in user's autostart directory.
+ *
+ * @return ERR_OK if created successfully, other error value if not.
+ */
+int    cfgfile_autostart_create        (void);
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Removes wchangerd desktop file from user's autostart directory.
+ *
+ * @return ERR_OK if removed successfully, ERR_FILE_RM if not.
+ */
+int    cfgfile_autostart_remove        (void);
 /*----------------------------------------------------------------------------*/
 #endif
 
