@@ -19,13 +19,13 @@
  *
  * @brief  Error info
  *
- * @author Michał Bąbik <michalb1981@o2.pl>
+ * @author Michal Babik <michal.babik@pm.me>
  */
 #ifndef ERRS_H
 #define ERRS_H
 /*----------------------------------------------------------------------------*/
 enum {
-    ERR_OK,      /**< OK */
+    ERR_OK = 0,  /**< OK */
     ERR_FILE,    /**< File error (cannot access / bad permissions) */
     ERR_FILE_RW, /**< File read / write error */
     ERR_FILE_CR, /**< File can not be created */
